@@ -20,6 +20,15 @@ typedef struct dynalogin_session_t {
 	apr_pool_t *pool;
 	apr_dso_handle_t *dso_handle;
 	dynalogin_datastore_module_t *datasource;
+
+	int hotp_digits;
+	int hotp_window;
+
+	int totp_digits;
+	int totp_window;
+	int totp_x;
+	int totp_t0;
+
 } dynalogin_session_t;
 
 /* Read any system settings, etc */
@@ -30,14 +39,17 @@ void dynalogin_done(dynalogin_session_t *h);
 
 dynalogin_result_t dynalogin_authenticate
 	(dynalogin_session_t *h, const dynalogin_userid_t userid,
-			const dynalogin_code_t code);
+			dynalogin_scheme_t scheme, const dynalogin_code_t code);
 
 dynalogin_result_t dynalogin_authenticate_digest
         (dynalogin_session_t *h, const dynalogin_userid_t userid,
-                        const char *response, const char *realm,
+        	dynalogin_scheme_t scheme, const char *response, const char *realm,
 			const char *digest_suffix);
 
 dynalogin_result_t dynalogin_read_config_from_file(apr_hash_t **config,
 		const char *filename, apr_pool_t *pool);
 
+dynalogin_scheme_t get_scheme_by_name(const char *scheme_name);
+const char *get_scheme_name(dynalogin_scheme_t scheme);
+
 #endif /* DYNALOGIN_H_ */
